@@ -9,7 +9,7 @@
   Github Repo: https://github.com/matmu/Qtlizer
   
   Citation appreciated:
-  Munz M, Wohlers I, Simon E, Busch H, Schaefer A* and Erdmann J* (2018) Qtlizer: comprehensive QTL annotation of GWAS results. bioRxiv DOI: https://doi.org/10.1101/495903
+  Munz M, Wohlers I, Simon E, Reinberger T, Busch H, Schaefer A and Erdmann J (2020) Qtlizer: comprehensive QTL annotation of GWAS results. Scientific Reports. doi:10.1038/s41598-020-75770-7
   
   ---------", domain = NULL, appendLF = TRUE)
-}
\ No newline at end of file
+}
